@@ -20,7 +20,7 @@
 namespace GParted
 { 
 
-TreeView_Detail::TreeView_Detail( )
+TreeView_Detail::TreeView_Detail()
 {
 	block = false ;
 	
@@ -31,25 +31,29 @@ TreeView_Detail::TreeView_Detail( )
 	treeselection ->signal_changed() .connect( sigc::mem_fun( *this, &TreeView_Detail::on_selection_changed ) );
 
 	//append columns
-	append_column( _("Partition"), treeview_detail_columns .partition );
+	append_column( _("Partition"), treeview_detail_columns .path );
 	append_column( _("Filesystem"), treeview_detail_columns .color );
+	append_column( _("Mountpoint"), treeview_detail_columns .mountpoint );
 	append_column( _("Size"), treeview_detail_columns .size );
 	append_column( _("Used"), treeview_detail_columns .used );
 	append_column( _("Unused"), treeview_detail_columns .unused );
 	append_column( _("Flags"), treeview_detail_columns .flags );
 	
-	//status_icon
-	get_column( 0 ) ->pack_start( treeview_detail_columns.status_icon, false );
-	
-	//filesystem text
-	get_column( 1 ) ->pack_start( treeview_detail_columns .filesystem, true );
-	
+	//icons
+	get_column( 0 ) ->pack_start( treeview_detail_columns .icon2, false );
+	get_column( 0 ) ->pack_start( treeview_detail_columns .icon1, false );
+
+	//PARTITION
 	//colored text in Partition column 
 	Gtk::CellRendererText *cell_renderer_text = 
 		dynamic_cast<Gtk::CellRendererText*>( get_column( 0 ) ->get_first_cell_renderer() );
 	get_column( 0 ) ->add_attribute( cell_renderer_text ->property_foreground(), 
 					 treeview_detail_columns .text_color );
 	
+	//FILESYSTEM
+	//filesystem text
+	get_column( 1 ) ->pack_start( treeview_detail_columns .filesystem, true );
+	
 	//colored text in Filesystem column 
 	std::vector<Gtk::CellRenderer*> renderers = get_column( 1 ) ->get_cell_renderers() ;
 	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( renderers .back() ) ;
@@ -59,13 +63,19 @@ TreeView_Detail::TreeView_Detail( )
 	//pixbuf and text are both left aligned
 	get_column( 1 ) ->get_first_cell_renderer() ->property_xalign() = Gtk::ALIGN_LEFT ;
 	cell_renderer_text ->property_xalign() = Gtk::ALIGN_LEFT ;
+	
+	//MOUNTPOINT
+	//colored text in mountpoint column 
+	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( get_column( 2 ) ->get_first_cell_renderer() );
+	get_column( 2 ) ->add_attribute( cell_renderer_text ->property_foreground(), 
+					 treeview_detail_columns .mount_text_color );
 
 	//set alignment of numeric columns to right
-	for( short t = 2 ; t < 5 ; t++ )
+	for( short t = 3 ; t < 6 ; t++ )
 		get_column_cell_renderer( t ) ->property_xalign() = 1 ;
-	
+
 	//expand columns and centeralign the headertext
-	for( short t = 2 ; t < 6 ; t++ )
+	for( short t = 3 ; t < 7 ; t++ )
 	{
 		get_column( t ) ->set_expand( true ) ;
 		get_column( t ) ->set_alignment( 0.5 ) ;
@@ -74,10 +84,11 @@ TreeView_Detail::TreeView_Detail( )
 
 void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions ) 
 {
+	bool mount_info = false ;
 	treestore_detail ->clear() ;
 	
 	for ( unsigned int i = 0 ; i < partitions .size() ; i++ ) 
-	{
+	{	
 		row = *( treestore_detail ->append() );
 		create_row( row, partitions[ i ] );
 		
@@ -87,14 +98,20 @@ void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions
 			{
 				childrow = *( treestore_detail ->append( row.children() ) );
 				create_row( childrow, partitions[ i ] .logicals[ t ] );
+		
+				if ( partitions[ i ] .logicals[ t ] .get_mountpoints() .size() )
+					mount_info = true ;
 			}
 		}
+
+		if ( partitions[ i ] .get_mountpoints() .size() )
+			mount_info = true ;
 	}
-	
-	//show logical partitions ( if any )
-	expand_all();
+
+	get_column( 2 ) ->set_visible( mount_info ) ;
 	
 	columns_autosize();
+	expand_all() ;
 }
 
 void TreeView_Detail::set_selected( const Partition & partition )
@@ -113,7 +130,7 @@ bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows, const Partiti
 {
 	for ( unsigned int t = 0 ; t < rows .size() ; t++ )
 	{
-		if ( static_cast<Partition>( rows[ t ] [ treeview_detail_columns .partition_struct ] ) == partition )
+		if ( static_cast<Partition>( rows[ t ] [ treeview_detail_columns .partition ] ) == partition )
 		{
 			if ( inside_extended )
 				expand_all() ;
@@ -131,21 +148,39 @@ bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows, const Partiti
 
 void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition & partition )
 {
-	//hereby i assume these 2 are mutual exclusive. is this wise?? Time (and bugreports) will tell :)
 	if ( partition .busy )
-		treerow[ treeview_detail_columns .status_icon ] = render_icon( Gtk::Stock::DIALOG_AUTHENTICATION, Gtk::ICON_SIZE_BUTTON );
-	else if ( partition .error != "" )
-		treerow[ treeview_detail_columns .status_icon ] = render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON );
+		treerow[ treeview_detail_columns .icon1 ] = 
+			render_icon( Gtk::Stock::DIALOG_AUTHENTICATION, Gtk::ICON_SIZE_BUTTON );
 	
-	treerow[ treeview_detail_columns .partition ] = partition .partition;
+	if ( ! partition .error .empty() )
+	{
+		if ( ! static_cast< Glib::RefPtr<Gdk::Pixbuf> >( treerow[ treeview_detail_columns .icon1 ] )  )
+			treerow[ treeview_detail_columns .icon1 ] = 
+				render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON );
+		else
+			treerow[ treeview_detail_columns .icon2 ] = 
+				render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON );
+	}
+
+	
+	treerow[ treeview_detail_columns .path ] = partition .get_path() ;
+
+	//this fixes a weird issue (see #169683 for more info)
+	if ( partition .type == GParted::TYPE_EXTENDED && partition .busy ) 
+		treerow[ treeview_detail_columns .path ] = treerow[ treeview_detail_columns .path ] + "   " ;
+
 	treerow[ treeview_detail_columns .color ] = Utils::get_color_as_pixbuf( partition .filesystem, 16, 16 ) ; 
 
 	treerow[ treeview_detail_columns .text_color ] = 
 		partition .type == GParted::TYPE_UNALLOCATED ? "darkgrey" : "black" ;
 	
 	treerow[ treeview_detail_columns .filesystem ] = 
-		Utils::Get_Filesystem_String( partition .filesystem ) ;
+		Utils::get_filesystem_string( partition .filesystem ) ;
 	
+	//mountpoint
+	treerow[ treeview_detail_columns .mount_text_color ] = partition .busy ? "black" : "darkgrey" ;
+	treerow[ treeview_detail_columns .mountpoint ] = Glib::build_path( ", ", partition .get_mountpoints() ) ;
+		
 	//size
 	treerow[ treeview_detail_columns .size ] = Utils::format_size( partition .get_length() ) ;
 	
@@ -158,10 +193,11 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition
 		partition .sectors_unused == -1 ? "---" : Utils::format_size( partition .sectors_unused ) ;
 
 	//flags	
-	treerow[ treeview_detail_columns .flags ] = " " + partition .flags ;
+	treerow[ treeview_detail_columns .flags ] = 
+		Glib::build_path( ", ", partition .flags ) ;
 	
 	//hidden column (partition object)
-	treerow[ treeview_detail_columns .partition_struct ] = partition;
+	treerow[ treeview_detail_columns .partition ] = partition;
 }
 
 bool TreeView_Detail::on_button_press_event( GdkEventButton * event )
@@ -189,7 +225,7 @@ void TreeView_Detail::on_selection_changed()
 	if ( ! block && treeselection ->get_selected() != 0 )
 	{
 		row = static_cast<Gtk::TreeRow>( * treeselection ->get_selected() ) ;
-		signal_partition_selected .emit( row[ treeview_detail_columns .partition_struct ], true ) ;
+		signal_partition_selected .emit( row[ treeview_detail_columns .partition ], true ) ;
 	}
 }
 	
